| Title: | Access to the List of Mammal Species of Colombia |
|---|---|
| Description: | The goal of 'mammalcol' is to provide easy access to a meticulously structured dataset of Colombian mammal species in R. The 2026 update includes comprehensive, detailed species accounts, and distribution information at departamental and municipal level. |
| Authors: | Diego J. Lizcano [aut, cre] (ORCID: <https://orcid.org/0000-0002-9648-0576>), Cristian A. Cruz-Rodríguez [ctb, aut] (ORCID: <https://orcid.org/0000-0002-8319-4706>), Andres F. Suárez-Castro [ctb, aut] (ORCID: <https://orcid.org/0000-0002-6621-3821>), Baltazar González [ctb, aut] (ORCID: <https://orcid.org/0000-0001-5805-8107>), Karol Aguilar-Rios [ctb, aut] (ORCID: <https://orcid.org/0009-0002-6331-2653>), Alejandra Bonilla-Sánchez [ctb] (ORCID: <https://orcid.org/0000-0003-0803-5884>), Camilo A. Calderón-Acevedo [ctb] (ORCID: <https://orcid.org/0000-0002-1468-3565>) |
| Maintainer: | Diego J. Lizcano <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.3.0 |
| Built: | 2026-06-06 06:44:34 UTC |
| Source: | https://github.com/dlizcano/mammalcol |
The distribution dataset comprises a data frame containing information regarding mammal species distribution documented in Colombia, sourced from the "List of the mammals of Colombia" compiled by Ramírez-Chaves 2021. It encompasses various details, including locality, source, threat status and appendix CITES of each species. The table is a variant of the distribution table from SiB Colombia
distributiondistribution
A data frame with 553 rows and 7 columns:
id from original taxon table.
Departamento were the mammal is present.
Code for Colombia.
Is endemic?. Endémica=Yes
categorization previous to 2021
Apendix from CITES
region were the species occurs.
This dataset is designed to provide users with comprehensive information about the mammal species found in each departamento of Colombia, as documented by Ramírez-Chaves 2021. The data set is organized for easy access and utilization within the R environment.
Data compilation: Ramírez-Chaves 2021, Package implementation: Diego J. Lizcano
The dataset is based on the "List of the Mammals of Colombia" by: Ramírez-Chaves H E, Leuro Robles N G, Castaño Rivera A, Morales-Martínez D M, Suárez Castro A F, Rodríguez-Posada M E, Zurc D, Concha Osbahr D C, Trujillo A, Noguera Urbano E A, Pantoja Peña G E, González Maya J F, Pérez Torres J, Mantilla Meluk H, López Castañeda C, Velásquez Valencia A, Zárrate Charry D (2024): Mamíferos de Colombia. v1.14. Sociedad Colombiana de Mastozoología. Dataset/Checklist SiB Colombia
For more information about the "mammalcol" package and the data sources, visit the package's GitHub repository: https://github.com/dlizcano/mammalcol
library (mammalcol) head (distribution)library (mammalcol) head (distribution)
This function validates species distribution data provided in a data frame against the known mammal species lists and a departamentos map. It outputs a data frame with validation results and additional information.
mamm_coords_validator( df, sp_names, taxon = NULL, colmap_d = NULL, lon = NULL, lat = NULL, adm_names = NULL, oceanmap = NULL, oce_adm_names = NULL )mamm_coords_validator( df, sp_names, taxon = NULL, colmap_d = NULL, lon = NULL, lat = NULL, adm_names = NULL, oceanmap = NULL, oce_adm_names = NULL )
df |
A data frame containing species distribution data with columns 'species', 'decimalLongitude', and 'decimalLatitude'. |
sp_names |
Name of the column containing species names (Genus + Specific Epithet). |
taxon |
A data frame with distribution information, including 'scientificName' and 'distribution'. The scientificName must be in binomial form, and the distribution should contain names separated by |. By default, the function uses the checklist available at https://www.gbif.org/dataset/e8b9ed9b-f715-4eac-ae24-772fbf40d7ae. |
colmap_d |
A spatial object in vector format representing the geographic area to validate against. By default, the function uses the Colombia Administrative Boundaries available in the geodata package. |
lon |
Name of the column containing longitude values in df. Default is 'decimalLongitude'. |
lat |
Name of the column containing latitude values in df. Default is 'decimalLatitude'. |
adm_names |
Name of the column in colmap representing administrative boundaries. Default is 'NAME_1'. |
oceanmap |
A spatial object representing the ocean area to validate against. |
oce_adm_names |
Name of the column in oceanmap representing administrative boundaries for ocean areas. Default is 'ocean'. |
This function validates species distribution data by checking species names against a known list and verifying geographic coordinates against political maps ('colmap_d' and 'oceanmap'). 'colmap_d' is downloaded internally using the geodata package. It assigns a validation result ('validation_result') where 1 means coincidence and 0 means no match. Additional details are provided in the returned data frame.
A data frame with validated species records and validation results.
validated_data <- mamm_coords_validator (df = test_data_coordiantes, sp_names = "species")validated_data <- mamm_coords_validator (df = test_data_coordiantes, sp_names = "species")
This function retrieve the locality data for one species in the mammalcol pacakage dataset, and returns a map using ggplot2 of the departamentos where the species has been recorded.
mammalmap(species, legend = TRUE)mammalmap(species, legend = TRUE)
species |
A character string containing the name of one species present in Colombia to plot a map of presence by departamento. |
legend |
A logical (TRUE or FALSE) to get the legend in the map when is TRUE, or not if it is FALSE. |
The function does not allows fuzzy matching, so the specie name should be correct. It is advised to run first the search_mammalcol function.
A ggplot2 map for the species.
library (mammalcol) species <- "Tapirus pinchaque" mammalmap (species, legend = FALSE)library (mammalcol) species <- "Tapirus pinchaque" mammalmap (species, legend = FALSE)
This function takes a list of Mammal species names, searches for their data in the MammalCol pacakage dataset, and returns a data frame containing the relevant information for each species.
search_mammalcol(splist, max_distance = 0.2)search_mammalcol(splist, max_distance = 0.2)
splist |
A character vector containing the names of the species to search for. |
max_distance |
The maximum allowed distance for fuzzy matching of species names. Defaults to 0.2. |
The function allows fuzzy matching for species names with a maximum distance threshold to handle potential typos or variations in species names.
A data frame containing the retrieved information for each species.
library(mammalcol) splist <- c("Tapirus bairdii", "Tapirus pinchaque", "Tapirus terrestris", "Tapirus terrestris", "tapir terrestre", "Pudu mephistophiles") search_mammalcol(splist)library(mammalcol) splist <- c("Tapirus bairdii", "Tapirus pinchaque", "Tapirus terrestris", "Tapirus terrestris", "tapir terrestre", "Pudu mephistophiles") search_mammalcol(splist)
Find the mammal species that occur in a given departamento of Colombia
sp_by_depto(states, type = c("any", "only", "all"), taxa = NULL)sp_by_depto(states, type = c("any", "only", "all"), taxa = NULL)
states |
a character vector with one or more departamento names |
type |
type of matching to be used. |
taxa |
optional character vector to match against the departamentos. Use the order name |
a data frame
library (mammalcol) occ.any <- sp_by_depto(c("Arauca", "Norte de Santander"), type = "any") occ.only <- sp_by_depto(c("Norte de Santander"), type = "only") occ.all <- sp_by_depto(c("Arauca", "Norte de Santander"), type = "all") occ.taxa <- sp_by_depto(c("Arauca", "Norte de Santander"), type = "all", taxa = "Chiroptera") head(occ.any) head(occ.only) head(occ.all) head(occ.taxa)library (mammalcol) occ.any <- sp_by_depto(c("Arauca", "Norte de Santander"), type = "any") occ.only <- sp_by_depto(c("Norte de Santander"), type = "only") occ.all <- sp_by_depto(c("Arauca", "Norte de Santander"), type = "all") occ.taxa <- sp_by_depto(c("Arauca", "Norte de Santander"), type = "all", taxa = "Chiroptera") head(occ.any) head(occ.only) head(occ.all) head(occ.taxa)
The taxon dataset comprises a tibble containing information regarding mammal species documented in Colombia, sourced from the "List of the mammals of Colombia" compiled by Ramírez-Chaves 2024. It encompasses various details, including scientific names, English names, Spanish names, order, family, threat status and distribution of each species. The table is a variant of the taxon table from SiB Colombia
taxontaxon
A tibble with 548 rows and 19 columns:
id from original taxon table.
Scientific name of the mammal species.
kingdom name of the mammal species.
phylum name of the mammal species.
class name of the mammal species.
order name of the mammal species.
family name of the mammal species.
genus name of the mammal species.
specificEpithet name of the mammal species.
taxon Rank name of the mammal species.
species name´s author of the mammal species.
elevation of the mammal species.
bibliographicCitation of the mammal species.
1 if it is included on the Mammal Diverity Data Base, 0 not included.
conservation status in Colombia for the mammal species.
Departamento were the mammal is present.
reference for the distribution.
Yes if it is endemic from Colombia, otherwise No.
english_name of the mammal species.
This dataset is designed to provide users with comprehensive information about the mammal species found in Colombia, as documented by Ramírez-Chaves, et al. 2025. It is organized for easy access and utilization within the R environment.
Data compilation: Ramírez-Chaves 2021, Function and Package implementation: Diego J. Lizcano
The dataset is based on the "List of the Mammals of Colombia" by: Ramírez-Chaves H E, Leuro Robles N G, Castaño Rivera A, Morales-Martínez D M, Suárez Castro A F, Rodríguez-Posada M E, Zurc D, Concha Osbahr D C, Trujillo A, Noguera Urbano E A, Pantoja Peña G E, González Maya J F, Pérez Torres J, Mantilla Meluk H, López Castañeda C, Velásquez Valencia A, Zárrate Charry D (2024): Mamíferos de Colombia. v1.14. Sociedad Colombiana de Mastozoología. Dataset/Checklist SiB Colombia
For more information about the "mammalcol" package and the data sources, visit the package's GitHub repository: https://github.com/dlizcano/mammalcol
# Load the mammalcol package library(mammalcol) # Access the mammalcol_tab dataset data("taxon") # Display the first few rows head(taxon)# Load the mammalcol package library(mammalcol) # Access the mammalcol_tab dataset data("taxon") # Display the first few rows head(taxon)
A test data set for the function mamm_coords_validator
test_data_coordiantestest_data_coordiantes
A tibble with 20 rows and 50 columns:
scientific name in binomial form
latitude
longitude
This data set provides a sample from GBIF to test the function mamm_coords_validator
Data compilation: Ramírez-Chaves 2021, Function implementation: Cristian A. Cruz-R.
The dataset is based on the "List of the Mammals of Colombia" by: Ramírez-Chaves H E, Leuro Robles N G, Castaño Rivera A, Morales-Martínez D M, Suárez Castro A F, Rodríguez-Posada M E, Zurc D, Concha Osbahr D C, Trujillo A, Noguera Urbano E A, Pantoja Peña G E, González Maya J F, Pérez Torres J, Mantilla Meluk H, López Castañeda C, Velásquez Valencia A, Zárrate Charry D (2024): Mamíferos de Colombia. v1.14. Sociedad Colombiana de Mastozoología. Dataset/Checklist SiB Colombia
For more information about the "mammalcol" package and the data sources, visit the package's GitHub repository: https://github.com/dlizcano/mammalcol
# Load the mammalcol package library (mammalcol) # Access the mammalcol_tab dataset data ("test_data_coordiantes") # Display the first few rows head (test_data_coordiantes)# Load the mammalcol package library (mammalcol) # Access the mammalcol_tab dataset data ("test_data_coordiantes") # Display the first few rows head (test_data_coordiantes)